( cd usr/share/doc/HTML/et/thesaurus ; rm -rf common )
( cd usr/share/doc/HTML/et/thesaurus ; ln -sf /usr/share/doc/HTML/et//common common )
( cd usr/share/doc/HTML/et/stage ; rm -rf common )
( cd usr/share/doc/HTML/et/stage ; ln -sf /usr/share/doc/HTML/et//common common )
( cd usr/share/doc/HTML/et/calligra ; rm -rf common )
( cd usr/share/doc/HTML/et/calligra ; ln -sf /usr/share/doc/HTML/et//common common )
( cd usr/share/doc/HTML/et/sheets ; rm -rf common )
( cd usr/share/doc/HTML/et/sheets ; ln -sf /usr/share/doc/HTML/et//common common )
